0.9.9 API documentation: matrix_interpolation.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_interpolation.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18
19 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
20 # ifndef GLM_ENABLE_EXPERIMENTAL
21 # pragma message("GLM: GLM_GTX_matrix_interpolation is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
22 # else
23 # pragma message("GLM: GLM_GTX_matrix_interpolation extension included")
24 # endif
25 #endif
26
27 namespace glm
28 {
31
34 template<typename T, qualifier Q>
35 GLM_FUNC_DECL void axisAngle(
36 mat<4, 4, T, Q> const& Mat, vec<3, T, Q> & Axis, T & Angle);
37
40 template<typename T, qualifier Q>
41 GLM_FUNC_DECL mat<4, 4, T, Q> axisAngleMatrix(
42 vec<3, T, Q> const& Axis, T const Angle);
43
46 template<typename T, qualifier Q>
47 GLM_FUNC_DECL mat<4, 4, T, Q> extractMatrixRotation(
48 mat<4, 4, T, Q> const& Mat);
49
53 template<typename T, qualifier Q>
54 GLM_FUNC_DECL mat<4, 4, T, Q> interpolate(
55 mat<4, 4, T, Q> const& m1, mat<4, 4, T, Q> const& m2, T const Delta);
56
58 }//namespace glm
59
60 #include "matrix_interpolation.inl"
glm::extractMatrixRotation
GLM_FUNC_DECL mat< 4, 4, T, Q > extractMatrixRotation(mat< 4, 4, T, Q > const &Mat)
Extracts the rotation part of a matrix.
glm::interpolate
GLM_FUNC_DECL mat< 4, 4, T, Q > interpolate(mat< 4, 4, T, Q > const &m1, mat< 4, 4, T, Q > const &m2, T const Delta)
Build a interpolation of 4 * 4 matrixes.
glm::axisAngle
GLM_FUNC_DECL void axisAngle(mat< 4, 4, T, Q > const &Mat, vec< 3, T, Q > &Axis, T &Angle)
Get the axis and angle of the rotation from a matrix.
glm::axisAngleMatrix
GLM_FUNC_DECL mat< 4, 4, T, Q > axisAngleMatrix(vec< 3, T, Q > const &Axis, T const Angle)
Build a matrix from axis and angle.
glm
Definition: common.hpp:20